==> systemsettings_5.12.4.orig.tar.xz: systemsettings-5.12.4/icons/CategorizedView.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Rafael Fernández López <ereslibre@kde.org>      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
 ***************************************************************************/

#ifndef CATEGORIZEDVIEW_H
#define CATEGORIZEDVIEW_H

#include <KCategorizedView>

class CategorizedView : public KCategorizedView
{
public:
    CategorizedView( QWidget *parent = 0 );

    void setModel( QAbstractItemModel *model ) Q_DECL_OVERRIDE;
protected:
    void wheelEvent(QWheelEvent *) Q_DECL_OVERRIDE;
};

#endif

==> systemsettings_5.20.5.orig.tar.xz: systemsettings-5.20.5/icons/CategorizedView.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Rafael Fernández López <ereslibre@kde.org>      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
 ***************************************************************************/

#ifndef CATEGORIZEDVIEW_H
#define CATEGORIZEDVIEW_H

#include <KCategorizedView>

class CategorizedView : public KCategorizedView
{
public:
    explicit CategorizedView( QWidget *parent = nullptr );

    void setModel( QAbstractItemModel *model ) override;
protected:
    void wheelEvent(QWheelEvent *) override;
};

#endif
